// Importing message helper function
const chalk = require('chalk');
const message = require('../../helpers/prompts/_message');

const promptsProject = [
    {
        type: 'input',
        name: 'projectName',
        message: message({
            headline: 'Project Name',
            description: 'Please provide a Project Name (without-spaces):',
            defaultValue: 'Current Name:'
        }),
        default() {
            return process.cwd()
                .split('/')
                .pop(-1)
                .toLowerCase()
                .replace(/\s/g, '');
        },
        validate(input) {
            // Do async stuff
            if (input.indexOf(' ') >= 0 || /[~`!#$%^&*+=[\]\\';,/{}|\\":<>?]/g.test(input)) {
                // Pass the return value in the done callback
                return `${chalk.styles.red.open}
No whitespaces or special-chars allowed!${chalk.styles.red.close}`;
            }
            return true;
        }
    },
    {
        type: 'input',
        name: 'projectDescription',
        message: message({
            headline: 'Project Description',
            description: 'Please provide a description for your project:',
            defaultValue: 'Current Description:'
        }),
        default: 'My Awesome Project'
    },
    {
        type: 'input',
        name: 'projectVersion',
        message: message({
            headline: 'Project Version',
            description: 'Define a Project Version:'
        }),
        default: '0.0.1'
    },
    {
        type: 'list',
        name: 'projectType',
        message: message({
            headline: 'Project Type',
            description: 'Choose your Project Type:',
            defaultValue: false
        }),
        choices: [
            {
                name: 'Craft CMS 3',
                value: 'craftCMS3'
            },
            {
                name: 'WordPress',
                value: 'wordpress'
            }
            /*
            {
                name: 'Vue Application',
                value: 'vueApp'
            }
            */
        ]
    },
    {
        type: 'input',
        name: 'projectProxy',
        message: message({
            headline: 'Project Proxy Domain',
            description: 'Define a Project Proxy.'
        }),
        default(answers) {
            // If the Answer includes .dev or .local
            if (answers.projectName.includes('.localhost') || answers.projectName.includes('.local') || answers.projectName.includes('.test')) {
                return answers.projectName;
            }
            return `${answers.projectName}.test`;
        },
        validate(input) {
            if (input !== false) {
                if (input.match(/(http|https):\/\//g) ||
                    !input.match(/^([a-zA-Z0-9-]+(\.[a-zA-Z0-9]+)+.*)$/g)) {
                    // Pass the return value in the done callback
                    return `${chalk.styles.red.open}
Not a valid URL! Example: foobar.test (or .local / .localhost) — (HOSTNAME.TLD)${chalk.styles.red.close}`;
                }
            }
            // Pass the return value in the done callback
            return true;
        }
    },
    {
        type: 'confirm',
        name: 'projectPrivateRepo',
        message: message({
            headline: 'Project Private',
            description: 'Is this a private Project (no public repo)?'
        }),
        default: true
    },
    {
        type: 'confirm',
        name: 'projectVue',
        message: message({
            headline: 'Project VueJS',
            description: 'Do you want to use Vue.js?'
        }),
        default: true
    }
];

module.exports = promptsProject;
